use std::env;
use std::io::{self, Write};
use std::process::Command;

fn retry(cmd: &String, cmd_args: &[String]) {
    loop {
        let output = Command::new(cmd)
            .args(cmd_args)
            .output()
            .map_err(|e| {
                eprintln!("Failed to execute command: {}", e);
                io::stderr().flush().unwrap();
            });

        match output {
            Ok(output) => {
                io::stdout().write_all(&output.stdout).unwrap();
                if output.status.success() {
                    break;
                }

                eprintln!("Command failed with status: {}", output.status);
                println!("{}", String::from_utf8_lossy(&output.stderr));
            }
            Err(_) => {
                println!("Error, wait 1s for retry.")
            }
        }

        std::thread::sleep(std::time::Duration::from_secs(1));
    }
}

fn main() {
    let args: Vec<String> = env::args().collect();

    if args.len() < 2 {
        eprintln!("Usage: {} <cmd> [args...]", args[0]);
        std::process::exit(1);
    }

    let cmd = &args[1];
    let cmd_args = if args.len() > 2 {
        &args[2..]
    } else {
        &[]
    };

    retry(cmd, cmd_args);
}
